@@ -44,11 +44,11 @@ import (
 func init() {
 	rootCmd.AddCommand(swiftDumpCmd)
 
-	swiftDumpCmd.Flags().BoolP("interface", "i", false, "Dump Swift Interface")
 	swiftDumpCmd.Flags().Bool("deps", false, "Dump imported private frameworks")
 	swiftDumpCmd.Flags().Bool("demangle", false, "Demangle symbol names")
 	swiftDumpCmd.Flags().Bool("all", false, "Dump all other Swift sections/info")
-	swiftDumpCmd.Flags().StringP("output", "o", "", "Folder to write headers to")
+	swiftDumpCmd.Flags().BoolP("interface", "i", false, "🚧 Dump Swift Interface")
+	swiftDumpCmd.Flags().StringP("output", "o", "", "🚧 Folder to write interface to")
 	swiftDumpCmd.MarkFlagDirname("output")
 	swiftDumpCmd.Flags().String("theme", "nord", "Color theme (nord, github, etc)")
 	swiftDumpCmd.RegisterFlagCompletionFunc("theme", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
@@ -61,10 +61,10 @@ func init() {
 	// swiftDumpCmd.Flags().Bool("re", false, "RE verbosity (with addresses)")
 	swiftDumpCmd.Flags().String("arch", "", "Which architecture to use for fat/universal MachO")
 
-	viper.BindPFlag("swift-dump.interface", swiftDumpCmd.Flags().Lookup("interface"))
 	viper.BindPFlag("swift-dump.deps", swiftDumpCmd.Flags().Lookup("deps"))
 	viper.BindPFlag("swift-dump.demangle", swiftDumpCmd.Flags().Lookup("demangle"))
 	viper.BindPFlag("swift-dump.all", swiftDumpCmd.Flags().Lookup("all"))
+	viper.BindPFlag("swift-dump.interface", swiftDumpCmd.Flags().Lookup("interface"))
 	viper.BindPFlag("swift-dump.output", swiftDumpCmd.Flags().Lookup("output"))
 	viper.BindPFlag("swift-dump.theme", swiftDumpCmd.Flags().Lookup("theme"))
 	viper.BindPFlag("swift-dump.type", swiftDumpCmd.Flags().Lookup("type"))
@@ -98,16 +98,19 @@ var swiftDumpCmd = &cobra.Command{
 		}
 		color.NoColor = viper.GetBool("no-color")
 
+		// Validate Flags
 		if viper.GetBool("swift-dump.interface") &&
 			(viper.GetString("swift-dump.type") != "" ||
 				viper.GetString("swift-dump.proto") != "" ||
 				viper.GetString("swift-dump.ext") != "") ||
 			viper.GetString("swift-dump.ass") != "" {
 			return fmt.Errorf("cannot dump --interface and use --type, --protocol, --ext or --ass flags")
+		} else if len(viper.GetString("swift-dump.output")) > 0 && !viper.GetBool("swift-dump.interface") {
+			return fmt.Errorf("cannot set --output without setting --interface")
 		}
 
-		if len(viper.GetString("class-dump.output")) > 0 {
-			if err := os.MkdirAll(viper.GetString("class-dump.output"), 0o750); err != nil {
+		if len(viper.GetString("swift-dump.output")) > 0 {
+			if err := os.MkdirAll(viper.GetString("swift-dump.output"), 0o750); err != nil {
 				return err
 			}
 		}
@@ -147,17 +150,17 @@ var swiftDumpCmd = &cobra.Command{
 					shortOptions = append(shortOptions, strings.ToLower(arch.SubCPU.String(arch.CPU)))
 				}
 
-				if len(viper.GetString("class-dump.arch")) > 0 {
+				if len(viper.GetString("swift-dump.arch")) > 0 {
 					found := false
 					for i, opt := range shortOptions {
-						if strings.Contains(strings.ToLower(opt), strings.ToLower(viper.GetString("class-dump.arch"))) {
+						if strings.Contains(strings.ToLower(opt), strings.ToLower(viper.GetString("swift-dump.arch"))) {
 							m = fat.Arches[i].File
 							found = true
 							break
 						}
 					}
 					if !found {
-						return fmt.Errorf("--arch '%s' not found in: %s", viper.GetString("class-dump.arch"), strings.Join(shortOptions, ", "))
+						return fmt.Errorf("--arch '%s' not found in: %s", viper.GetString("swift-dump.arch"), strings.Join(shortOptions, ", "))
 					}
 				} else {
 					choice := 0
@@ -169,7 +172,7 @@ var swiftDumpCmd = &cobra.Command{
 					m = fat.Arches[choice].File
 				}
 			}
-			if viper.GetBool("class-dump.deps") {
+			if viper.GetBool("swift-dump.deps") {
 				log.Error("cannot dump imported private frameworks from a MachO file (only from a DSC)")
 			}
 
@@ -233,7 +236,7 @@ var swiftDumpCmd = &cobra.Command{
 		}
 
 		if viper.GetString("swift-dump.type") != "" {
-			if err := s.DumpType(viper.GetString("class-dump.type")); err != nil {
+			if err := s.DumpType(viper.GetString("swift-dump.type")); err != nil {
 				return err
 			}
 		}
@@ -258,8 +261,8 @@ var swiftDumpCmd = &cobra.Command{
 
 		if viper.GetString("swift-dump.type") == "" &&
 			viper.GetString("swift-dump.proto") == "" &&
-			viper.GetString("cswiftlass-dump.ext") == "" &&
-			viper.GetString("cswiftlass-dump.ass") == "" {
+			viper.GetString("swift-dump.ext") == "" &&
+			viper.GetString("swift-dump.ass") == "" {
 			return s.Dump()
 		}
 
