@@ -15,6 +15,7 @@ import (
 
 	"github.com/blacktop/go-macho"
 	"github.com/blacktop/go-plist"
+	fwcmd "github.com/blacktop/ipsw/internal/commands/fw"
 	"github.com/blacktop/ipsw/internal/download"
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/blacktop/ipsw/pkg/dyld"
@@ -194,7 +195,7 @@ func SPTM(c *Config) ([]string, error) {
 
 		folder := filepath.Join(filepath.Clean(c.Output), strings.TrimPrefix(filepath.Dir(f), tmpDIR))
 		fname := filepath.Join(folder, strings.TrimSuffix(filepath.Base(f), ".im4p"))
-		if err := os.MkdirAll(folder, 0750); err != nil {
+		if err := os.MkdirAll(folder, 0o750); err != nil {
 			return nil, fmt.Errorf("failed to create output directory '%s': %v", folder, err)
 		}
 
@@ -203,12 +204,12 @@ func SPTM(c *Config) ([]string, error) {
 			if err != nil {
 				return nil, fmt.Errorf("failed to decompress '%s': %v", f, err)
 			}
-			if err = os.WriteFile(fname, dat, 0660); err != nil {
+			if err = os.WriteFile(fname, dat, 0o666); err != nil {
 				return nil, fmt.Errorf("failed to write '%s': %v", fname, err)
 			}
 			outfiles = append(outfiles, fname)
 		} else {
-			if err = os.WriteFile(fname, im4p.Data, 0660); err != nil {
+			if err = os.WriteFile(fname, im4p.Data, 0o666); err != nil {
 				return nil, fmt.Errorf("failed to write '%s': %v", fname, err)
 			}
 			outfiles = append(outfiles, fname)
@@ -218,6 +219,80 @@ func SPTM(c *Config) ([]string, error) {
 	return outfiles, nil
 }
 
+func Exclave(c *Config) ([]string, error) {
+	var tmpOut []string
+	var outfiles []string
+
+	origOutput := c.Output
+
+	tmpDIR, err := os.MkdirTemp("", "ipsw_extract_exclave")
+	if err != nil {
+		return nil, fmt.Errorf("failed to create temporary directory to store Exlave im4p: %v", err)
+	}
+	defer os.RemoveAll(tmpDIR)
+	c.Output = tmpDIR
+
+	c.Pattern = `.*exclavecore_bundle.*im4p$`
+	out, err := Search(c)
+	if err != nil {
+		return nil, err
+	}
+	if len(out) == 0 {
+		return nil, fmt.Errorf("no Exclave bundles found")
+	}
+
+	tmpOut = append(tmpOut, out...)
+
+	c.Output = origOutput
+
+	for _, f := range tmpOut {
+		if strings.Contains(f, ".restore.") {
+			continue // TODO: skip restore bundles for now
+		}
+		dat, err := os.ReadFile(f)
+		if err != nil {
+			return nil, fmt.Errorf("failed to open '%s': %v", f, err)
+		}
+
+		im4p, err := img4.ParseIm4p(bytes.NewReader(dat))
+		if err != nil {
+			return nil, fmt.Errorf("failed to parse '%s': %v", f, err)
+		}
+
+		folder := filepath.Join(filepath.Clean(c.Output), strings.TrimPrefix(filepath.Dir(f), tmpDIR))
+		fname := filepath.Join(folder, strings.TrimSuffix(filepath.Base(f), ".im4p"))
+		if err := os.MkdirAll(folder, 0o750); err != nil {
+			return nil, fmt.Errorf("failed to create output directory '%s': %v", folder, err)
+		}
+
+		if bytes.Contains(im4p.Data[:4], []byte("bvx2")) {
+			dat, err = lzfse.NewDecoder(im4p.Data).DecodeBuffer()
+			if err != nil {
+				return nil, fmt.Errorf("failed to decompress '%s': %v", f, err)
+			}
+			if err = os.WriteFile(fname, dat, 0o666); err != nil {
+				return nil, fmt.Errorf("failed to write '%s': %v", fname, err)
+			}
+			outfiles = append(outfiles, fname)
+		} else {
+			if err = os.WriteFile(fname, im4p.Data, 0o666); err != nil {
+				return nil, fmt.Errorf("failed to write '%s': %v", fname, err)
+			}
+			outfiles = append(outfiles, fname)
+		}
+	}
+
+	for _, exc := range outfiles {
+		out, err := fwcmd.Extract(exc, filepath.Dir(exc))
+		if err != nil {
+			return nil, fmt.Errorf("failed to extract files from exclave bundle: %v", err)
+		}
+		outfiles = append(outfiles, out...)
+	}
+
+	return outfiles, nil
+}
+
 // DSC extracts the DSC file from an IPSW
 func DSC(c *Config) ([]string, error) {
 	if len(c.IPSW) > 0 {
@@ -370,10 +445,10 @@ func Keybags(c *Config) (fname string, err error) {
 	}
 
 	fname = filepath.Join(filepath.Join(filepath.Clean(c.Output), folder), "kbags.json")
-	if err := os.MkdirAll(filepath.Dir(fname), 0750); err != nil {
+	if err := os.MkdirAll(filepath.Dir(fname), 0o750); err != nil {
 		return "", fmt.Errorf("failed to create directory %s: %v", filepath.Dir(fname), err)
 	}
-	if err := os.WriteFile(fname, out, 0660); err != nil {
+	if err := os.WriteFile(fname, out, 0o666); err != nil {
 		return "", fmt.Errorf("failed to write %s: %v", filepath.Join(filepath.Join(filepath.Clean(c.Output), folder), "kbags.json"), err)
 	}
 
